@@ -14,6 +14,8 @@ var bombs = new Array(10); //Max of 10 bombs on screen at one time
 var score = 0;
 var dropBombChance = 2; //start chance of and alien dropping a bomb
 var alienStartSpeed = 600; //the speed the aliens move at teh start of the level
+var alienMaxSpeed = 100; //the maximum speed
+var alienSpeedRatio = 0.9 //The speed increase on the next level
 
 var level = 0;
 var startlives = 3; //Edit this to cheat!
@@ -36,6 +38,9 @@ function cmdNotRunning() {
     alienanimation.running = false;
 
     board.hideMessage();
+
+    starttimer1.restart();
+    starttimer2.restart();
 }
 
 function cmdNewGame() {
@@ -56,6 +61,12 @@ function cmdNewGame() {
     destroyLivesIndication();
     createLivesIndication();
 
+    //Hide the logos
+    starttimer1.stop();
+    starttimer2.stop();
+    spacelogo.state = "HIDDEN";
+    invaderslogo.state = "HIDDEN";
+
     cmdStartNewLevel();
 }
 
@@ -143,13 +154,20 @@ function cmdLevelComplete() {
 
     cleanupBombs();
 
-    if (alienStartSpeed > 200) {
-        alienStartSpeed -= 50;
+    if (alienStartSpeed > alienMaxSpeed) {
+        alienStartSpeed = Math.floor(alienStartSpeed * alienSpeedRatio)
     }
 
     if (dropBombChance > 50) {
         dropBombChance -= 10; //drop more bombs!
     }
+
+    //New Life every 10 levels
+    if (((level % 5) == 0) && (lives < 8) && (level != 5)) {
+        lives++;
+        createLivesIndication();
+        board.displayMessage("Extra Life Gained!");
+    }
 }
 
 function cmdStartNewLevel() {
@@ -223,7 +241,7 @@ function createLivesIndication() {
 
     py = board.height - ship.height;
 
-    for (var i = 0; i < startlives-1; ++i) {
+    for (var i = 0; i < lives-1; ++i) {
         px = i * (ship.width + 20);
 
         var component = Qt.createComponent("Ship.qml");
